package com.hexace.editor.services
{
    import com.hexace.editor.model.CustomerModel;
    import com.hexace.editor.model.FunctionalityModel;
    import com.hexace.editor.model.ModuleModel;
    import com.hexace.editor.model.vo.customer.Customer;
    import com.hexace.editor.model.vo.functionality.Functionality;
    import com.hexace.editor.model.vo.module.Module;

    public class ConfigParser implements IConfigParser
    {
        [Inject]
        public var customerModel:CustomerModel;

        [Inject]
        public var functionalityModel:FunctionalityModel;


        [Inject]
        public var moduleModel:ModuleModel;
        private var _data:XML;

        public function set data(v:XML):void
        {
            _data=v;
            mapVOsToModels();
        }

        public function mapVOsToModels():void
        {
            //customermodel
            customerModel.customer=parseCustomer();

            var modules:Vector.<Module>=parseModules(customerModel.customer.id);
            //moduleModel
            for (var mi:uint=0; mi < modules.length; mi++)
            {
                var module:Module=modules[mi] as Module;
                moduleModel.mapModule(module);

                var functionalities:Vector.<Functionality>=parseFunctionalitiesForModule(module.id);
                //functionalityModel
                for (var fi:uint=0; fi < functionalities.length; fi++)
                {
                    var functionality:Functionality=functionalities[fi] as Functionality;
                    functionalityModel.mapFunctionality(functionality);
                }
            }
        }

        public function parseCustomer():Customer
        {
            trace("ConfigParser.parseCustomer()");
            var customer:Customer=new Customer(_data.customer.@name, _data.customer.databaseName, _data.customer.databaseUser, _data.customer.databasePass, _data.customer.id);

            return customer;
        }

        public function parseModules(customerId:uint):Vector.<Module>
        {
            trace("ConfigParser.parseModules(customerId)");
            var modules:Vector.<Module>=new Vector.<Module>();

            for each (var item:XML in _data.customer.module)
            {
                var module:Module=new Module(item.@name, item.@type, item.@id, item.@customerId);
                modules.push(module);
            }
            return modules;
        }

        public function parseFunctionalitiesForModule(moduleId:uint):Vector.<Functionality>
        {
            trace("ConfigParser.parseFunctionalitiesForModule(moduleId)");

            var functionalities:Vector.<Functionality>=new Vector.<Functionality>;

            for each (var item:XML in _data.customer.module.(@id == moduleId).functionality)
            {
                var functionality:Functionality=new Functionality(item.@type, item.@moduleId, item.@id);
                functionalities.push(functionality);
            }
            return functionalities;
        }
    }
}
